@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2016 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2016-2021 <tsujan2000@gmail.com>
  *
  * FeatherNotes is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -93,15 +93,15 @@ static bool findBackward (const QTextDocument *txtdoc, const QString &str,
 /*************************/
 // This method extends the searchable strings to those with line breaks.
 // It also corrects the behavior of Qt's backward search.
-QTextCursor FN::finding (const QString& str,
-                         const QTextCursor& start,
+QTextCursor FN::finding (const QString &str,
+                         const QTextCursor &start,
                          QTextDocument::FindFlags flags) const
 {
     /* let's be consistent first */
     if (ui->stackedWidget->currentIndex() == -1 || str.isEmpty())
         return QTextCursor(); // null cursor
 
-    TextEdit *textEdit = qobject_cast< TextEdit *>(ui->stackedWidget->currentWidget());
+    TextEdit *textEdit = qobject_cast<TextEdit*>(ui->stackedWidget->currentWidget());
     QTextDocument *txtdoc = textEdit->document();
     QTextCursor res = QTextCursor (start);
     if (str.contains ('\n'))
@@ -187,7 +187,7 @@ QTextCursor FN::finding (const QString& str,
                             i = 0;
                             continue;
                         }
-                        cursor.setPosition (cursor.anchor() + subStr.count());
+                        cursor.setPosition (cursor.anchor() + subStr.size());
                         break;
                     }
                     else
@@ -234,7 +234,7 @@ QTextCursor FN::finding (const QString& str,
                         while (cursor.anchor() > cursor.block().position())
                         {
                             /* ... move the cursor to left and search backward until a match is found */
-                            cursor.setPosition (cursor.block().position() + subStr.count());
+                            cursor.setPosition (cursor.block().position() + subStr.size());
                             if (!findBackward (txtdoc, subStr, cursor, flags))
                                 return QTextCursor();
                         }
@@ -280,7 +280,7 @@ QTextCursor FN::finding (const QString& str,
                             i = 0;
                             continue;
                         }
-                        cursor.setPosition (cursor.anchor() - subStr.count());
+                        cursor.setPosition (cursor.anchor() - subStr.size());
                         break;
                     }
                     else
@@ -327,7 +327,7 @@ void FN::find()
         return;
     }
     else
-        closeTagsDialog();
+        closeWinDialogs();
 
     if (ui->namesButton->isChecked())
     {
@@ -335,7 +335,7 @@ void FN::find()
         return;
     }
 
-    TextEdit *textEdit = qobject_cast< TextEdit *>(cw);
+    TextEdit *textEdit = qobject_cast<TextEdit*>(cw);
     disconnect (textEdit->verticalScrollBar(), &QAbstractSlider::valueChanged, this, &FN::scrolled);
     disconnect (textEdit->horizontalScrollBar(), &QAbstractSlider::valueChanged, this, &FN::scrolled);
     disconnect (textEdit, &TextEdit::resized, this, &FN::hlight);
@@ -376,7 +376,7 @@ void FN::find()
     QModelIndex nxtIndx;
     if (found.isNull())
     {
-        if (!ui->everywhereButton->isChecked() || model_->rowCount() == 1)
+        if (!ui->everywhereButton->isChecked())
         {
             if (backwardSearch)
                 start.movePosition (QTextCursor::End, QTextCursor::MoveAnchor);
@@ -400,7 +400,11 @@ void FN::find()
                     if (!backwardSearch)
                         nxtIndx = model_->index (0, 0);
                     else
+                    {
                         nxtIndx = model_->index (model_->rowCount() - 1, 0);
+                        while (model_->hasChildren (nxtIndx))
+                            nxtIndx = model_->index (model_->rowCount (nxtIndx) - 1, 0, nxtIndx);
+                    }
                 }
                 DomItem *item = static_cast<DomItem*>(nxtIndx.internalPointer());
                 if (TextEdit *thisTextEdit = widgets_.value (item))
@@ -438,7 +442,7 @@ void FN::find()
     {
         searchingOtherNode_ = true;
         ui->treeView->setCurrentIndex (nxtIndx); // selChanged() is called immediately
-        textEdit = qobject_cast< TextEdit *>(ui->stackedWidget->currentWidget());
+        textEdit = qobject_cast<TextEdit*>(ui->stackedWidget->currentWidget());
         ui->lineEdit->setText (txt);
         searchEntries_[textEdit] = txt;
         find();
@@ -451,25 +455,33 @@ void FN::hlight() const
     QWidget *cw = ui->stackedWidget->currentWidget();
     if (!cw) return;
 
-    TextEdit *textEdit = qobject_cast< TextEdit *>(cw);
+    TextEdit *textEdit = qobject_cast<TextEdit*>(cw);
     const QString txt = searchEntries_[textEdit];
     if (txt.isEmpty()) return;
 
     QList<QTextEdit::ExtraSelection> extraSelections;
     /* prepend green highlights */
     extraSelections.append (greenSels_[textEdit]);
-    QColor yellow = QColor (Qt::yellow);
-    QColor black = QColor (Qt::black);
-    QTextCursor found;
-    /* first put a start cursor at the top left edge... */
+
+    /* first put a start cursor at the top left corner... */
     QPoint Point (0, 0);
     QTextCursor start = textEdit->cursorForPosition (Point);
-    /* ... then move it backward by the search text length */
-    int startPos = start.position() - txt.length();
-    if (startPos >= 0)
-        start.setPosition (startPos);
-    else
+    if (textEdit->verticalScrollBar()->value() == textEdit->verticalScrollBar()->minimum()
+        && textEdit->horizontalScrollBar()->value() == textEdit->horizontalScrollBar()->minimum())
+    {
+        /* WARNING: "QTextEdit::cursorForPosition()" has a bug that may
+           give an irrelevant cursor for (0, 0) with newly created widgets. */
         start.setPosition (0);
+    }
+    else
+    {
+        /* ... then move it backward by the search text length */
+        int startPos = start.position() - txt.length();
+        if (startPos >= 0)
+            start.setPosition (startPos);
+        else
+            start.setPosition (0);
+    }
     int w = textEdit->geometry().width();
     int h = textEdit->geometry().height();
     /* get the visible text to check if
@@ -486,13 +498,15 @@ void FN::hlight() const
     Qt::CaseSensitivity cs = ui->caseButton->isChecked() ? Qt::CaseSensitive : Qt::CaseInsensitive;
     if (str.contains (txt, cs)) // don't waste time if the searched text isn't visible
     {
+        QColor yellow = qGray (fgColor_.rgb()) > 127 ? QColor (Qt::darkYellow) : QColor (Qt::yellow);
+        QTextCursor found;
         while (!(found = finding (txt, start, searchFlags_)).isNull())
         {
             QTextEdit::ExtraSelection extra;
             extra.format.setBackground (yellow);
             extra.format.setFontUnderline (true);
             extra.format.setUnderlineStyle (QTextCharFormat::WaveUnderline);
-            extra.format.setUnderlineColor (black);
+            extra.format.setUnderlineColor (fgColor_);
             extra.cursor = found;
             extraSelections.append (extra);
             start.setPosition (found.position());
@@ -522,7 +536,7 @@ void FN::reallySetSearchFlags (bool h)
     {
         for (int i = 0; i < ui->stackedWidget->count(); ++i)
         {
-            TextEdit *textEdit = qobject_cast< TextEdit *>(ui->stackedWidget->widget (i));
+            TextEdit *textEdit = qobject_cast<TextEdit*>(ui->stackedWidget->widget (i));
             QTextCursor start = textEdit->textCursor();
             start.setPosition (start.anchor());
             textEdit->setTextCursor (start);
