@@ -17,7 +17,8 @@
 
 #include "textedit.h"
 #include <QDesktopServices>
-//#include <QProcess>
+#include <QStandardPaths>
+#include <QProcess>
 #include <QToolTip>
 #include <QTimer>
 #include <QTextBlock>
@@ -887,7 +888,7 @@ void TextEdit::mouseMoveEvent (QMouseEvent *e)
 {
     QTextEdit::mouseMoveEvent (e);
 
-    QString str = anchorAt (e->pos());
+    QString str = anchorAt (e->position().toPoint());
     if (!str.isEmpty())
         viewport()->setCursor (Qt::PointingHandCursor);
     else
@@ -944,7 +945,7 @@ void TextEdit::mousePressEvent (QMouseEvent *e)
     QTextEdit::mousePressEvent (e);
 
     if (e->button() == Qt::LeftButton)
-        pressPoint_ = e->pos();
+        pressPoint_ = e->position().toPoint();
 }
 
 /*************************/
@@ -954,17 +955,20 @@ void TextEdit::mouseReleaseEvent (QMouseEvent *e)
     if (e->button() != Qt::LeftButton)
         return;
 
-    QString str = anchorAt (e->pos());
+    QString str = anchorAt (e->position().toPoint());
     if (!str.isEmpty()
-        && cursorForPosition (e->pos()) == cursorForPosition (pressPoint_))
+        && cursorForPosition (e->position().toPoint()) == cursorForPosition (pressPoint_))
     {
         QUrl url (str);
         if (url.isRelative()) // treat relative URLs as local paths
             url = QUrl::fromUserInput (str, "/", QUrl::AssumeLocalFile);
         /* QDesktopServices::openUrl() may resort to "xdg-open", which isn't
            the best choice. "gio" is always reliable, so we check it first. */
-        //if (!QProcess::startDetached ("gio", QStringList() << "open" << url.toString()))
+        if (QStandardPaths::findExecutable ("gio").isEmpty()
+            || !QProcess::startDetached ("gio", QStringList() << "open" << url.toString()))
+        {
             QDesktopServices::openUrl (url);
+        }
     }
     pressPoint_ = QPoint();
 }
